@@ -175,7 +175,7 @@ Some sites from which RINEX files can be downloaded for free are ::
 __author__ = "David Woodburn"
 __credits__ = []
 __license__ = "MIT"
-__date__ = "2022-05-06"
+__date__ = "2022-05-18"
 __maintainer__ = "David Woodburn"
 __email__ = "david.woodburn@icloud.com"
 __status__ = "Development"
@@ -808,7 +808,9 @@ class Obs:
                 else:
                     state = STATE_HEADER
             elif state == STATE_EPOCH:
-                if label[0].isalpha() or label[0] == '#':
+                # If this line is a comment or no space vehicles are listed,
+                # skip this line.
+                if label[0].isalpha() or label[0] == '#' or line[32] == ' ':
                     state = STATE_EPOCH
                     continue
 
@@ -856,7 +858,6 @@ class Obs:
                 else:
                     state = STATE_OBS
 
-                # NOTE Receiver clock offset is ignored.
             elif state == STATE_MORE_SVS:
                 # Read more space vehicle PRNs.
                 N = svs_epoch_left if svs_epoch_left < 12 else 12
